Class: Bio::Ngs::Bwa::Sampe

Inherits:
Object
  • Object
show all
Includes:
Command::Wrapper
Defined in:
lib/bio/appl/ngs/bwa.rb

Overview

Usage: bwa sampe [options] <in1.sai> <in2.sai> <in1.fq> <in2.fq>

Options: -a INT maximum insert size [500] -o INT maximum occurrences for one end [100000] -n INT maximum hits to output for paired reads [3] -N INT maximum hits to output for discordant pairs [10] -c FLOAT prior of chimeric rate (lower bound) [1.0e-05] -f FILE sam file to output results to [stdout] -r STR read group header line such as `@RG\tID:foo\tSM:bar' [null] -P preload index into memory (for base-space reads only) -s disable Smith-Waterman for the unmapped mate -A disable insert size estimate (force -s)

Method Summary

Methods included from Command::Wrapper

#class_name, #default_options, included, #initialize, #normalize_params, #options, #options=, #output, #params, #params=, #path, #path=, #pipe_ahead, #pipe_ahead=, #pipe_ahead?, #program, #reset_params, #run, #sub_program, #thor_task, #to_cmd_ary, #use_aliases?