Class: Bio::Ngs::Cufflinks::GffRead

Inherits:
Object
  • Object
show all
Includes:
Command::Wrapper
Defined in:
lib/bio/appl/ngs/cufflinks.rb

Overview

-E expose (warn about) duplicate transcript IDs and other potential problems with the given GFF/GTF records -Z merge close exons into a single exon (for intron size<4) -w write a fasta file with spliced exons for each GFF transcript -x write a fasta file with spliced CDS for each GFF transcript -W for -w and -x options, also write for each fasta record the exon coordinates projected onto the spliced sequence -y write a protein fasta file with the translation of CDS for each record -L Ensembl GTF to GFF3 conversion (implies -F; should be used with -m) -m <chr_replace> is a reference (genomic) sequence replacement table with this format: <original_ref_ID> <new_ref_ID> GFF records on reference sequences that are not found among the <original_ref_ID> entries in this file will be filtered out -o the "filtered" GFF records will be written to <outfile.gff> (use -o- for printing to stdout) -t use in the second column of each GFF output line -T -o option will output GTF format instead of GFF3

Method Summary

Methods included from Command::Wrapper

#class_name, #default_options, included, #initialize, #normalize_params, #options, #options=, #output, #params, #params=, #path, #path=, #pipe_ahead, #pipe_ahead=, #pipe_ahead?, #program, #reset_params, #run, #sub_program, #thor_task, #to_cmd_ary, #use_aliases?